@@ -126,7 +126,7 @@ class TestExclusiveWriteOrPass(test_base.BaseTest):
 
     def test_write(self):
         wrote = dnsmasq._exclusive_write_or_pass(self.path, self.buf)
-        self.assertEqual(True, wrote)
+        self.assertTrue(wrote)
         self.mock_open.assert_called_once_with(self.path, 'w', 1)
         self.mock_fcntl.assert_has_calls(
             [self.fcntl_lock_call, self.fcntl_unlock_call])
@@ -144,7 +144,7 @@ class TestExclusiveWriteOrPass(test_base.BaseTest):
             None, None]
         wrote = dnsmasq._exclusive_write_or_pass(self.path, self.buf)
 
-        self.assertEqual(True, wrote)
+        self.assertTrue(wrote)
         self.mock_open.assert_called_once_with(self.path, 'w', 1)
         self.mock_fcntl.assert_has_calls(
             [self.fcntl_lock_call, self.fcntl_unlock_call],
@@ -164,7 +164,7 @@ class TestExclusiveWriteOrPass(test_base.BaseTest):
         self.mock_fcntl.side_effect = [err, None]
 
         wrote = dnsmasq._exclusive_write_or_pass(self.path, self.buf)
-        self.assertEqual(False, wrote)
+        self.assertFalse(wrote)
         self.mock_open.assert_called_once_with(self.path, 'w', 1)
         self.mock_fcntl.assert_has_calls(
             [self.fcntl_lock_call, self.fcntl_unlock_call])
